pub fn escape_dot_string(s: &str) -> String
Escapes characters in a string to be valid within a DOT label, tooltip, or attribute value. Ensures the output is enclosed in double quotes if needed (e.g., for labels/tooltips).